# frozen_string_literal: true

#
# This function checks if oim is configured in the specified path.
#
#
# See the file "LICENSE" for the full license governing this code.
#
Puppet::Functions.create_function(:'wls_install::oim_configured') do
  dispatch :oim_configured do
    param 'String', :domain_dir
    return_type 'Boolean'
  end

  def oim_configured(domain_dir)
    scope = closure_scope
    fact = scope['wls_install_domains']
    if fact.keys.empty?
      call_function('wls_install::log', 'oim_configured no domains found, return false')
      return false
    else
      fact.each_key do |domain|
        oim = fact[domain]['oimconfigured']
        if oim && (fact[domain]['path'] == domain_dir)
          call_function('wls_install::log', "oim_configured in path '#{domain_dir}', return true")
          return true
        end
      end
    end
    call_function('wls_install::log', "oim_configured no oim configured in path '#{domain_dir}', return false")
    false
  end
end
