# frozen_string_literal: true

#
# This function parses a Hash of patches and looks for resources with
# sub_patches. If they are there, this function will translate it to the
# actual list of patches that need to be on the system.
#
#
# See the file "LICENSE" for the full license governing this code.
#

Puppet::Functions.create_function(:'wls_install::wls_physical_patches') do
  dispatch :physical_patches do
    param 'Hash', :patch_list
    return_type 'Array'
  end

  def physical_patches(patch_list)
    return [] if patch_list.nil?

    patch_list.keys.collect do |full_patch_id|
      remove = true if patch_list[full_patch_id].key?('ensure') && (patch_list[full_patch_id]['ensure'].to_s == 'absent')
      oracle_home, _patch_id = full_patch_id.split(':')
      sub_patches = patch_list[full_patch_id]['sub_patches']
      if sub_patches
        if remove
          sub_patches.collect { |p| "#{oracle_home}:#{p}:remove" }
        else
          sub_patches.collect { |p| "#{oracle_home}:#{p}" }
        end
      elsif remove
        "#{full_patch_id}:remove"
      else
        full_patch_id
      end
    end.compact.flatten
  end
end
