#
# wls_install::software
#
# @summary 
# This class allows you install the WebLogic software on your system. Here is an example on how you could use this:```class{'ora_install::software':  version              => 1221,                       # 1036|1211|1212|1213|1221  filename             => 'fmw_12.2.1.0.0_wls.jar',   #   jdk_home_dir         => '/usr/java/jdk1.8.0_45',  oracle_base_home_dir => "/opt/oracle",  middleware_home_dir  => "/opt/oracle/middleware12c",  weblogic_home_dir    => "/opt/oracle/middleware12c/wlserver",  os_user              => "oracle",  os_group             => "dba",  download_dir         => "/data/install",  source               => "/vagrant",                 # puppet:///modules/orawls/ | /mnt |  logoutput           => true,}```
#
#
#
# See the file "LICENSE" for the full license governing this code.
#
class wls_install::software (
  Stdlib::Absolutepath           $download_dir         = undef,
  String[1]                      $filename             = undef,
  Boolean                        $fmw_infra            = false,
  String                         $java_parameters      = '',
  Stdlib::Absolutepath           $jdk_home_dir         = undef,
  Variant[
    Boolean,
    Enum[
      'on_failure',
    ]
  ]                              $logoutput            = lookup({ name => 'logoutput', default_value => 'on_failure' }),
  Stdlib::Absolutepath           $middleware_home_dir  = undef,
  Stdlib::Absolutepath           $oracle_base_home_dir = undef,
  Optional[Stdlib::Absolutepath] $oracle_inventory_dir = undef,
  String[1]                      $os_group             = undef,
  String[1]                      $os_user              = undef,
  String[1]                      $source               = undef,
  Stdlib::Absolutepath           $temp_directory       = '/tmp',
  Wls_install::Versions          $version              = 1111,
  Optional[Stdlib::Absolutepath] $weblogic_home_dir    = undef,
  Optional[Stdlib::Absolutepath] $wls_apps_dir         = undef,
  Optional[Stdlib::Absolutepath] $wls_domains_dir      = undef
) {
  easy_type::debug_evaluation() # Show local variable on extended debug

  wls_install::software_version { 'base':
    version              => $version,
    filename             => $filename,
    oracle_base_home_dir => $oracle_base_home_dir,
    middleware_home_dir  => $middleware_home_dir,
    weblogic_home_dir    => $weblogic_home_dir,
    wls_domains_dir      => $wls_domains_dir,
    wls_apps_dir         => $wls_apps_dir,
    fmw_infra            => $fmw_infra,
    jdk_home_dir         => $jdk_home_dir,
    os_user              => $os_user,
    os_group             => $os_group,
    download_dir         => $download_dir,
    source               => $source,
    oracle_inventory_dir => $oracle_inventory_dir,
    java_parameters      => $java_parameters,
    logoutput            => $logoutput,
    temp_directory       => $temp_directory,
  }
}
