#
# wls_install::support::files
#
# @summary Support class ensuring neccecary files.
#
#
#
#
# See the file "LICENSE" for the full license governing this code.
#
class wls_install::support::files (
  Boolean              $custom_trust              = false,
  Boolean              $jsse_enabled              = $wls_install::support::params::jsse_enabled,
  String[1]            $node_mgr_address          = $wls_install::support::params::node_mgr_address,
  Stdlib::Absolutepath $node_mgr_path             = $wls_install::support::params::node_mgr_path,
  Integer              $node_mgr_port             = $wls_install::support::params::node_mgr_port,
  String[1]            $ora_group                 = $wls_install::support::params::ora_group,
  Stdlib::Absolutepath $ora_inventory             = $wls_install::support::params::ora_inventory,
  String[1]            $ora_user                  = $wls_install::support::params::ora_user,
  String[1]            $os_domain                 = $wls_install::support::params::os_domain,
  Stdlib::Absolutepath $os_domain_path            = $wls_install::support::params::os_domain_path,
  String[1]            $os_domain_type            = $wls_install::support::params::os_domain_type,
  Stdlib::Absolutepath $os_download_folder        = $wls_install::support::params::os_download_folder,
  Stdlib::Absolutepath $os_log_folder             = $wls_install::support::params::os_log_folder,
  Stdlib::Absolutepath $os_mdw_home               = $wls_install::support::params::os_mdw_home,
  Stdlib::Absolutepath $os_oracle_home            = $wls_install::support::params::os_oracle_home,
  Stdlib::Absolutepath $os_wl_home                = $wls_install::support::params::os_wl_home,
  Optional[String[1]]  $trust_keystore_file       = undef,
  Optional[Easy_type::Password]
  $trust_keystore_passphrase = undef,
  String[1]            $wls_adminserver           = $wls_install::support::params::wls_adminserver,
  Easy_type::Password  $wls_password              = $wls_install::support::params::wls_password,
  String[1]            $wls_user                  = $wls_install::support::params::wls_user
) inherits wls_install::support::params {
  $root_group = lookup('wls_install::root_group', String[1])

  easy_type::debug_evaluation() # Show local variable on extended debug

  case $facts['kernel'] {
    'Linux', 'SunOS', 'AIX': {
      $mode = '0775'

      $shell = $wls_install::support::params::shell
      $user_home = $wls_install::support::params::user_home
      $ora_inst_home = $wls_install::support::params::ora_inst_home

      # lint:ignore:140chars
      if ( $custom_trust ) {
        $trust_env = "-Dweblogic.security.TrustKeyStore=CustomTrust -Dweblogic.security.CustomTrustKeyStoreFileName=${trust_keystore_file} -Dweblogic.security.CustomTrustKeystorePassPhrase=${trust_keystore_passphrase.unwrap}"
      } else {
        $trust_env = ''
      }
      # lint:endignore

      unless ( defined(File['/opt/scripts']) ) {
        file { '/opt/scripts':
          ensure => directory,
          owner  => $ora_user,
          group  => $ora_group,
          mode   => $mode,
        }
      }

      unless ( defined(File['/opt/scripts/wls']) ) {
        file { '/opt/scripts/wls':
          ensure  => directory,
          owner   => $ora_user,
          group   => $ora_group,
          mode    => $mode,
          require => File['/opt/scripts'],
        }
      }

      file { 'showStatus.sh':
        ensure  => file,
        path    => '/opt/scripts/wls/showStatus.sh',
        content => regsubst(epp('wls_install/wls/showStatus.sh.epp', {
              'os_domain_type'  => $os_domain_type,
              'wls_adminserver' => $wls_adminserver,
              'shell'           => $shell,
        }), '\r\n', "\n", 'EMG'),
        owner   => $ora_user,
        group   => $ora_group,
        mode    => $mode,
        require => File['/opt/scripts/wls'],
      }

      file { 'stopNodeManager.sh':
        ensure  => file,
        path    => '/opt/scripts/wls/stopNodeManager.sh',
        content => regsubst(epp('wls_install/wls/stopNodeManager.sh.epp', {
              'shell' => $shell,
        }), '\r\n', "\n", 'EMG'),
        owner   => $ora_user,
        group   => $ora_group,
        mode    => $mode,
        require => File['/opt/scripts/wls'],
      }

      file { 'cleanOracleEnvironment.sh':
        ensure  => file,
        path    => '/opt/scripts/wls/cleanOracleEnvironment.sh',
        content => regsubst(epp('wls_install/cleanOracleEnvironment.sh.epp', {
              'shell'              => $shell,
              'os_oracle_home'     => $os_oracle_home,
              'os_download_folder' => $os_download_folder,
              'os_mdw_home'        => $os_mdw_home,
              'os_wl_home'         => $os_wl_home,
              'ora_user'           => $ora_user,
              'oracle_home'        => $user_home,
              'ora_inst_home'      => $ora_inst_home,
              'os_log_folder'      => $os_log_folder,
              'ora_inventory'      => $ora_inventory,
        }), '\r\n', "\n", 'EMG'),
        owner   => 'root',
        group   => $root_group,
        mode    => '0770',
        require => File['/opt/scripts/wls'],
      }

      file { 'startNodeManager.sh':
        ensure  => file,
        path    => '/opt/scripts/wls/startNodeManager.sh',
        content => regsubst(epp('wls_install/startNodeManager.sh.epp', {
              'shell'         => $shell,
              'jsse_enabled'  => $jsse_enabled,
              'trust_env'     => $trust_env,
              'node_mgr_path' => $node_mgr_path,
        }), '\r\n', "\n", 'EMG'),
        owner   => $ora_user,
        group   => $ora_group,
        mode    => $mode,
        require => File['/opt/scripts/wls'],
      }

      file { 'startWeblogicAdmin.sh':
        ensure  => file,
        path    => '/opt/scripts/wls/startWeblogicAdmin.sh',
        content => regsubst(epp('wls_install/startWeblogicAdmin.sh.epp', {
              'shell'            => $shell,
              'os_wl_home'       => $os_wl_home,
              'os_domain'        => $os_domain,
              'os_domain_path'   => $os_domain_path,
              'node_mgr_port'    => $node_mgr_port,
              'node_mgr_address' => $node_mgr_address,
              'wls_user'         => $wls_user,
              'wls_password'     => $wls_password,
              'wls_adminserver'  => $wls_adminserver,
              'jsse_enabled'     => $jsse_enabled,
              'trust_env'        => $trust_env,
        }), '\r\n', "\n", 'EMG'),
        owner   => $ora_user,
        group   => $ora_group,
        mode    => $mode,
        require => File['/opt/scripts/wls'],
      }

      file { 'stopWeblogicAdmin.sh':
        ensure  => file,
        path    => '/opt/scripts/wls/stopWeblogicAdmin.sh',
        content => regsubst(epp('wls_install/stopWeblogicAdmin.sh.epp', {
              'shell'            => $shell,
              'os_wl_home'       => $os_wl_home,
              'os_domain'        => $os_domain,
              'os_domain_path'   => $os_domain_path,
              'node_mgr_port'    => $node_mgr_port,
              'node_mgr_address' => $node_mgr_address,
              'wls_user'         => $wls_user,
              'wls_password'     => $wls_password,
              'wls_adminserver'  => $wls_adminserver,
              'jsse_enabled'     => $jsse_enabled,
              'trust_env'        => $trust_env,
        }), '\r\n', "\n", 'EMG'),
        owner   => $ora_user,
        group   => $ora_group,
        mode    => $mode,
        require => File['/opt/scripts/wls'],
      }
    }
    default: {
      notify { 'This operating system is not supported': }
    }
  }
}
