#
# wls_install::utils::oimconfig
#
# @summary 
# This defined type allows you to configure OIM , oim server, design or remote configuration. Here is an example on how you could use this:```ora_install::utils::oimconfig{ 'oimDomain':  version                 => 1112,  oim_home                => '/opt/oracle/middleware11g/Oracle_IDM1',  server_config           => true,  oim_password            => 'Welcome01',  remote_config           => false,  keystore_password       => 'Welcome01',  design_config           => false,  oimserver_hostname      => 'oim1admin.example.com',  oimserver_port          => '14000',  repository_database_url => "oimdb.example.com:1521:oimrepos.example.com",  repository_prefix       => "DEV",  repository_password     => "Welcome01",}```
#
# @param [Wls_install::Versions] version
#    The version that is installed in the used Oracle home.
#    Puppet uses this value to decide on version specific actions.
#
# @param [Stdlib::Absolutepath] oim_home
#    Directory to contain the OIM home.
#
# @param [Boolean] server_config
#    
#
# @param [Easy_type::Password] oim_password
#    OIM password.
#
# @param [Boolean] remote_config
#    
#
# @param [Easy_type::Password] keystore_password
#    Password to use when opening the keystore.
#
# @param [Boolean] design_config
#    Boolean to determine if you want to config oim design.
#
# @param [String[1]] oimserver_hostname
#    Hostname for the oimserver.
#
# @param [Integer] oimserver_port
#    IP port for the OIM server.
#
# @param [String[1]] soaserver_name
#    Name of the SOA server.
#
# @param [String[1]] oimserver_name
#    Name to use for the OIM server.
#
# @param [Boolean] bi_enabled
#    Boolean to determine if you want BI enabled.
#
# @param [Optional[String[1]]] bi_cluster_name
#    Cluster where BI is running.
#
# @param [Optional[String[1]]] repository_database_url
#    The jdbc URL of the RCU repository.
#
# @param [String[1]] repository_prefix
#    Extra prefix to use for the RCU.
#
# @param [Easy_type::Password] repository_password
#    The password to use for accessing the RCU repository.
#
# @param [Stdlib::Absolutepath] jdk_home_dir
#    The homdirectory for the Java evelopment Kit.
#
# @param [Stdlib::Absolutepath] weblogic_home_dir
#    Directory to use as WebLogic home.
#
# @param [Stdlib::Absolutepath] middleware_home_dir
#    Middleware home directory.
#
# @param [Stdlib::Absolutepath] wls_domains_dir
#    The root directory where all domain directories reside in.
#
# @param [String[1]] domain_name
#    The domain name.
#
# @param [String[1]] adminserver_name
#    The name of the Admin Server.
#
# @param [String[1]] adminserver_address
#    The address of the admin server.
#    May be a DNS name or a physical IP address.
#
# @param [Integer] adminserver_port
#    The IP port the admin server is listening on.
#
# @param [Integer] nodemanager_port
#    The IP port the nodemanager is listening on.
#
# @param [String[1]] weblogic_user
#    The base WebLogic username to configure.
#
# @param [Easy_Type::Password] weblogic_password
#    The password of the base WebLogic user name.
#
# @param [String[1]] os_user
#    The os user used to install and run WebLogic.
#
# @param [String[1]] os_group
#    The os group used to install and run WebLogic.
#
# @param [Stdlib::Absolutepath] download_dir
#    The directory where the Puppet software puts all downloaded files.
#    Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
#    The default value is: `/install`
#
# @param [Variant[Boolean, Enum['on_failure']]] logoutput
#    log the outputs of Puppet exec or not.
#    When you specify `true` Puppet will log all output of `exec` types.
#    Valid values are:
#    - `true`
#    - `false`
#    - `on_failure`
#
#
# See the file "LICENSE" for the full license governing this code.
#
# lint:ignore:no_erb_template
define wls_install::utils::oimconfig (
  Wls_install::Versions $version                 = undef,
  Stdlib::Absolutepath  $oim_home                = undef,
  Boolean               $server_config           = false,
  Easy_type::Password   $oim_password            = undef,
  Boolean               $remote_config           = false,
  Easy_type::Password   $keystore_password       = undef,
  Boolean               $design_config           = false,
  String[1]             $oimserver_hostname      = undef,
  Integer               $oimserver_port          = 14000,
  String[1]             $soaserver_name          = 'soa_server1',
  String[1]             $oimserver_name          = 'oim_server1',
  Boolean               $bi_enabled              = false,
  Optional[String[1]]   $bi_cluster_name         = undef,
  Optional[String[1]]   $repository_database_url = lookup({ name => 'repository_database_url', default_value => undef }),
  String[1]             $repository_prefix       = lookup({ name => 'repository_prefix', default_value => 'DEV' }),
  Easy_type::Password   $repository_password     = lookup({ name => 'repository_password', default_value => 'Welcome01' }),
  Stdlib::Absolutepath  $jdk_home_dir            = lookup({ name => 'wls_jdk_home_dir' }),
  Stdlib::Absolutepath  $weblogic_home_dir       = lookup({ name => 'wls_weblogic_home_dir' }),
  Stdlib::Absolutepath  $middleware_home_dir     = lookup({ name => 'wls_middleware_home_dir' }),
  Stdlib::Absolutepath  $wls_domains_dir         = lookup({ name => 'wls_domains_dir', default_value => undef }),
  String[1]             $domain_name             = lookup({ name => 'domain_name' }),
  String[1]             $adminserver_name        = lookup({ name => 'domain_adminserver', default_value => 'AdminServer' }),
  String[1]             $adminserver_address     = lookup({ name => 'domain_adminserver_address', default_value => 'localhost' }),
  Integer               $adminserver_port        = lookup({ name => 'domain_adminserver_port', default_value => 7001 }),
  Integer               $nodemanager_port        = lookup({ name => 'domain_nodemanager_port', default_value => 5556 }),
  String[1]             $weblogic_user           = lookup({ name => 'wls_weblogic_user', default_value => 'weblogic' }),
  Easy_Type::Password   $weblogic_password       = lookup({ name => 'domain_wls_password' }),
  String[1]             $os_user                 = lookup({ name => 'wls_os_user' }),
  String[1]             $os_group                = lookup({ name => 'wls_os_group' }),
  Stdlib::Absolutepath  $download_dir            = lookup({ name => 'wls_download_dir' }),
  Variant[
    Boolean,
    Enum[
      'on_failure',
    ]
  ]                     $logoutput            = lookup({ name => 'logoutput', default_value => 'on_failure' }),
) {
  if ( $wls_domains_dir ) {
    $domains_dir = $wls_domains_dir
  } else {
    $domains_dir = "${middleware_home_dir}/user_projects/domains"
  }

  $domain_dir = "${domains_dir}/${domain_name}"

  $exec_path = "${jdk_home_dir}/bin:/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin:"

  easy_type::debug_evaluation() # Show local variable on extended debug

  if ( $remote_config ) {
    file { "${download_dir}/${title}config_oim_remote.rsp":
      ensure  => file,
      content => epp('wls_install/oim/oim_remote.rsp.epp', {
          'oim_home'          => $oim_home,
          'keystore_password' => $keystore_password,
      }),
      mode    => '0775',
      owner   => $os_user,
      group   => $os_group,
      backup  => false,
    }

    exec { "config oim remote ${title}":
      command   => "${oim_home}/bin/config.sh -silent -response ${download_dir}/${title}config_oim_remote.rsp -waitforcompletion",
      timeout   => 0,
      require   => File["${download_dir}/${title}config_oim_remote.rsp"],
      path      => $exec_path,
      user      => $os_user,
      group     => $os_group,
      logoutput => $logoutput,
    }
  }

  if ( $design_config ) {
    file { "${download_dir}/${title}config_oim_design.rsp":
      ensure    => file,
      content   => epp('wls_install/oim/oim_design.rsp.epp', {
          'oim_home'           => $oim_home,
          'oimserver_hostname' => $oimserver_hostname,
          'oimserver_port'     => $oimserver_port,
      }),
      mode      => '0775',
      owner     => $os_user,
      group     => $os_group,
      backup    => false,
      show_diff => false,
    }

    exec { "config oim design ${title}":
      command   => "${oim_home}/bin/config.sh -silent -response ${download_dir}/${title}config_oim_design.rsp -waitforcompletion",
      timeout   => 0,
      require   => File["${download_dir}/${title}config_oim_design.rsp"],
      path      => $exec_path,
      user      => $os_user,
      group     => $os_group,
      logoutput => $logoutput,
    }
  }

  if ( $server_config ) {
    # check if oim is already configured in this weblogic domain
    $oim_value = wls_install::oim_configured( $domain_dir )

    unless ( $oim_value ) {
      file { "${download_dir}/${title}config_oim_server.rsp":
        ensure    => file,
        content   => template('wls_install/oim/oim_server.rsp.erb'),
        mode      => '0775',
        owner     => $os_user,
        group     => $os_group,
        backup    => false,
        show_diff => false,
      }
      exec { "config oim server ${title}":
        command   => "/bin/sh -c 'unset DISPLAY;${oim_home}/bin/config.sh -silent -response ${download_dir}/${title}config_oim_server.rsp -waitforcompletion -debug -logLevel fine'",
        timeout   => 0,
        require   => File["${download_dir}/${title}config_oim_server.rsp"],
        path      => $exec_path,
        user      => $os_user,
        group     => $os_group,
        logoutput => $logoutput,
      }

      if ( $bi_enabled ) {
        # the py script used by the wlst
        file { "${download_dir}/§{title}.py":
          ensure    => file,
          content   => template('wls_install/wlst/wlstexec/fmw/bi-createUDD.py.erb'),
          backup    => false,
          show_diff => false,
          replace   => true,
          mode      => '0775',
          owner     => $os_user,
          group     => $os_group,
        }

        case $facts['kernel'] {
          'Linux': {
            $java_statement = 'java'
          }
          'SunOS': {
            $java_statement = 'java -d64'
          }
          default: {
            fail("Unrecognized operating system ${facts['kernel']}")
          }
        }

        $java_command = "${java_statement} -Dweblogic.security.SSL.ignoreHostnameVerification=true weblogic.WLST -skipWLSModuleScanning "
        # execute WLST script
        exec { "execwlst bi-createUDD.py ${title}":
          command     => "${java_command} ${download_dir}/bi-createUDD${title}.py ${weblogic_password.unwrap}",
          environment => [
            "CLASSPATH=${weblogic_home_dir}/server/lib/weblogic.jar",
            "JAVA_HOME=${jdk_home_dir}",
          ],
          path        => $exec_path,
          user        => $os_user,
          group       => $os_group,
          logoutput   => $logoutput,
          require     => [
            File["${download_dir}/bi-createUDD${title}.py"],
            Exec["config oim server ${title}"]
          ],
          before      => Wls_install::Control['stopOIMOimServer1AfterConfig'],
        }
      }

      wls_install::control { 'stopOIMOimServer1AfterConfig':
        middleware_home_dir => $middleware_home_dir,
        weblogic_home_dir   => $weblogic_home_dir,
        jdk_home_dir        => $jdk_home_dir,
        wls_domains_dir     => $domains_dir,
        domain_name         => $domain_name,
        server_type         => 'managed',
        target              => 'Server',
        server              => $oimserver_name,
        adminserver_address => $adminserver_address,
        adminserver_port    => $adminserver_port,
        nodemanager_port    => $nodemanager_port,
        action              => 'stop',
        weblogic_user       => $weblogic_user,
        weblogic_password   => $weblogic_password,
        os_user             => $os_user,
        os_group            => $os_group,
        download_dir        => $download_dir,
        logoutput           => $logoutput,
        require             => Exec["config oim server ${title}"],
      }

      wls_install::control { 'stopOIMSoaServer1AfterConfig':
        middleware_home_dir => $middleware_home_dir,
        weblogic_home_dir   => $weblogic_home_dir,
        jdk_home_dir        => $jdk_home_dir,
        wls_domains_dir     => $domains_dir,
        domain_name         => $domain_name,
        server_type         => 'managed',
        target              => 'Server',
        server              => $soaserver_name,
        adminserver_address => $adminserver_address,
        adminserver_port    => $adminserver_port,
        nodemanager_port    => $nodemanager_port,
        action              => 'stop',
        weblogic_user       => $weblogic_user,
        weblogic_password   => $weblogic_password,
        os_user             => $os_user,
        os_group            => $os_group,
        download_dir        => $download_dir,
        logoutput           => $logoutput,
        require             => [
          Wls_install::Control['stopOIMOimServer1AfterConfig'],
          Exec["config oim server ${title}"]
        ],
      }

      wls_install::control { 'stopOIMAdminServerAfterConfig':
        middleware_home_dir => $middleware_home_dir,
        weblogic_home_dir   => $weblogic_home_dir,
        jdk_home_dir        => $jdk_home_dir,
        wls_domains_dir     => $domains_dir,
        domain_name         => $domain_name,
        server_type         => 'admin',
        target              => 'Server',
        server              => $adminserver_name,
        adminserver_address => $adminserver_address,
        adminserver_port    => $adminserver_port,
        nodemanager_port    => $nodemanager_port,
        action              => 'stop',
        weblogic_user       => $weblogic_user,
        weblogic_password   => $weblogic_password,
        os_user             => $os_user,
        os_group            => $os_group,
        download_dir        => $download_dir,
        logoutput           => $logoutput,
        require             => [
          Wls_install::Control['stopOIMOimServer1AfterConfig'],
          Wls_install::Control['stopOIMSoaServer1AfterConfig'],
          Exec["config oim server ${title}"]
        ],
      }

      wls_install::control { 'startOIMAdminServerAfterConfig':
        middleware_home_dir => $middleware_home_dir,
        weblogic_home_dir   => $weblogic_home_dir,
        jdk_home_dir        => $jdk_home_dir,
        wls_domains_dir     => $domains_dir,
        domain_name         => $domain_name,
        server_type         => 'admin',
        target              => 'Server',
        server              => $adminserver_name,
        adminserver_address => $adminserver_address,
        adminserver_port    => $adminserver_port,
        nodemanager_port    => $nodemanager_port,
        action              => 'start',
        weblogic_user       => $weblogic_user,
        weblogic_password   => $weblogic_password,
        os_user             => $os_user,
        os_group            => $os_group,
        download_dir        => $download_dir,
        logoutput           => $logoutput,
        require             => [
          Wls_install::Control['stopOIMOimServer1AfterConfig'],
          Wls_install::Control['stopOIMAdminServerAfterConfig'],
          Wls_install::Control['stopOIMSoaServer1AfterConfig'],
          Exec["config oim server ${title}"]
        ],
      }
    }
  }
}
# lint:endignore:no_erb_template
