#
# See the file "LICENSE" for the full license governing this code.
#
# == define: wls_install::utils::orainst
#
#  creates oraInst.loc for oracle products
#
#
##
define wls_install::utils::orainst (
  Stdlib::Absolutepath $ora_inventory_dir = undef,
  String[1]            $os_group          = undef,
) {
  case $facts['kernel'] {
    'Linux', 'AIX': {
      $ora_inst_path        = '/etc'
    }
    'SunOS': {
      $ora_inst_path        = '/var/opt/oracle'
      unless ( defined(File[$ora_inst_path]) ) {
        file { $ora_inst_path:
          ensure => directory,
          before => File["${ora_inst_path}/oraInst.loc"],
          mode   => '0755',
        }
      }
    }
    default: {
      fail("Unrecognized operating system ${facts['kernel']}, please use it on a Linux host")
    }
  }

  easy_type::debug_evaluation() # Show local variable on extended debug

  unless ( defined(File["${ora_inst_path}/oraInst.loc"]) ) {
    file { "${ora_inst_path}/oraInst.loc":
      ensure  => file,
      content => epp('wls_install/utils/oraInst.loc.epp', {
          'ora_inventory_dir' => $ora_inventory_dir,
          'os_group'          => $os_group,
      }),
      mode    => '0755',
    }
  }
}
